% SIS2OU_ILLUSTRATION Approximation of SIS by OU.

% S. Engblom 2021-06-15 (derived from SIS2OU)
% S. Engblom 2021-01-25

figure(1), clf,
col = 'brk'; i = 0;
R0_ = [1.1 1.5 2];
Iinf = 1-1./R0_;
compile = 1;
for R0 = R0_
  i = i+1;
  %% 1) setup SIS-model first (notation from the main paper)
  Sigma = 1000;
  gamma = 1; % e.g., days^-1 to recover
  beta = R0*gamma;
  % (short transient of ~10 days, then stationary)

  Tend = 30;
  tt = linspace(0,Tend,100);
  X0 = [NaN; ceil(1e-2*Sigma)]; % [S I]
  X0(1) = Sigma-X0(2);

  %% 2) simulate as an ODE
  Frhs = @(t,X)[-(beta/Sigma)*prod(X)+gamma*X(2); ...
                (beta/Sigma)*prod(X)-gamma*X(2)];
  [ttode,Xode] = ode45(Frhs,linspace(0,Tend,15),X0);
  Xode = Xode/Sigma;

  plot(ttode,Xode(:,2),[col(i) 'o']); hold on

  %% 3) approximate by an OU SDE (only I)

  % mapping determined analytically by hand
  mu = gamma*(R0-1);
  k = gamma*Sigma*(R0-1)^2/R0;
  sigma = sqrt(2*gamma*Sigma*(R0-1)/R0);

  Xou = OU_process(k,mu,sigma,tt,X0(2));
  Xou = [Sigma-Xou' Xou']/Sigma;
  plot(tt,Xou(:,2),col(i));

  %% 4) simulate as a CTMC (requires URDME)
  clear umod;
  umod.vol = Sigma;
  umod.D = sparse(zeros(2));
  umod = rparse_inline(umod,{'S+I > beta > I+I','I > gamma > S'}, ...
                       {'S' 'I'},{'beta' beta 'gamma' gamma});
  umod.sd = 1;
  umod.u0 = X0;
  umod.tspan = tt;
  umod = urdme(umod,'compile',compile,'solver','ssa','seed',5); % (some seeds die off)
  compile = 0; % avoid re-compiling
  Xctmc = umod.U';
  Xctmc = Xctmc/Sigma;
  stairs(tt,Xctmc(:,2),[col(i) '--']);
end

ylim([0 Iinf(end)*1.5]);
set(gca,'xtick',[],'ytick',Iinf,'yticklabel',[]);
xlabel('t','interpreter','latex','fontsize',10);
ylabel('P(t)','interpreter','latex','fontsize',10);
h = legend('ODE','$\mathcal{OU}$','CTMC','interpreter','latex','fontsize',8);
set(h,'Position',[0.1321 0.6806 0.2826 0.2412]);
set(gcf,'PaperPositionMode','auto');
set(gcf,'Position',[100 100 350 170]);
%print -depsc ~/Desktop/SIS_illu.eps