function w = normfit_nomass(x,freq,w0)
%NORMFIT_NOMASS Normal density at unknown probability mass.
%   W = NORMFIT_NOMASS(X,FREQ,W0) fits a normal density to a sampled
%   pdf (X,FREQ). On entry, W0(1) is an estimate of the integral of
%   FREQ within the sample window [min(X) max(X)] (consider using
%   W0(1) = TRAPZ(X,FREQ) if nothing better is available) and W0(2:3)
%   are the estimated mean and standard deviation, respectively. On
%   return, W contains fitted versions of these same characteristics.

% S. Engblom 2021-08-13

xx = [min(x) max(x)];
rhs = @(w,x)normpdf(x,w(1),w(2))*w0(1)/diff(normcdf(xx,w(1),w(2)));
[w,~,~,flag] = lsqcurvefit(rhs,w0(2:3),x,freq,[],[], ...
                           optimoptions(@lsqcurvefit,'Display','none'));
w = [diff(normcdf(xx,w(1),w(2))) w];
if flag ~= 1
  switch flag,
   case 2, disp('Change in X too small.');
   case 3, disp('Change in RESNORM too small.');
   case 4, disp('Computed search direction too small.');
   case 0, disp('Too many function evaluations or iterations.');
   case -1, disp('Stopped by output/plot function.');
   case -2, disp('Bounds are inconsistent.');
  end
end
